Crate signet_types

Crate signet_types 

Signet-related types and utilities used throughout the SDK and node.

This is a utility and data-type crate. As a result its documentation is boring.

Re-exports

pub use signet_constants as constants;

Modules

primitives
Primitive block types used in Signet.

Structs

AggregateFills
The aggregate fills, to be populated via block extracts. Generally used to hold a running total of fills for a given user and asset across a block or set of transactions.
AggregateOrders
Aggregated orders for a transaction or set of transactions.
MagicSig
A magic signature, containing information about the host-chain event which caused the rollup transaction to occur.
PairedHeights
A pair of heights, one for the host chain and one for the rollup chain.
SignRequest
A request to sign a rollup block.
SignResponse
A signature response from a RequestSigner.
SignedFill
SignedFill type is constructed by Fillers to fill a batch of Orders. It represents the Orders’ Outputs after they have been permit2-encoded and signed.
SignedOrder
A SignedOrder represents a single Order after it has been permit2-encoded and signed. It is the final format signed by Users and shared with Fillers to request that an Order be filled.
UnsignedFill
An UnsignedFill is a builder type used to easily transform Orders or AggregateOrders into a SignedFill with correct permit2 semantics.
UnsignedOrder
An UnsignedOrder is a helper type used to easily transform an Order into a SignedOrder with correct permit2 semantics. Users can do: let signed_order = UnsignedOrder::from(order).with_chain(rollup_chain_id, rollup_order_address).sign(signer)?; TxCache::new(tx_cache_endpoint).forward_order(signed_order);

Enums

MagicSigInfo
Type flag used to identify the Signet event that cauesd the rollup consensus to create this magic signature.
MarketError
Error type for market processing.
SignedPermitError
An error that can occur when validating a signed order or fill.
SigningError
An error that can occur when signing an Order or a Fill.

Traits

RequestSigner
A RequestSigner signs SignRequests by delegating to an alloy::signers::Signer.

Functions

alias_address
Alias an address by adding the address alias offset.
unalias_address
Unalias an address by subtracting the address alias offset.