#[non_exhaustive]pub enum MagicSigInfo {
Enter,
EnterToken,
Transact {
sender: Address,
aliased: bool,
},
}Expand description
Type flag used to identify the Signet event that cauesd the rollup consensus to create this magic signature.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Enter
An enter event.
EnterToken
An enter token event.
Transact
A transact event.
Fields
aliased: boolWhether the sender address was aliased. This is set by the system,
and could be set for any reason. It causes the output of
Self::rollup_sender to be aliased according to Optimism
conventions.
Typically, this is true for Transact events emitted by
non-ephemeral contracts.
Implementations
Sourceimpl MagicSigInfo
impl MagicSigInfo
Sourcepub fn write_into_s(&self, buf: &mut [u8])
pub fn write_into_s(&self, buf: &mut [u8])
Write the magic signature info into a buffer.
Sourcepub fn read_from_s(s: impl AsRef<[u8]>) -> Option<Self>
pub fn read_from_s(s: impl AsRef<[u8]>) -> Option<Self>
Read the magic signature info from a signature S value.
Sourcepub const fn raw_sender(&self) -> Address
pub const fn raw_sender(&self) -> Address
Get the sender from the magic signature info. For enter and enter token
events, this is the MINTER_ADDRESS. For transact events, this is the
sender.
Sourcepub fn rollup_sender(&self) -> Address
pub fn rollup_sender(&self) -> Address
Get the rollup sender from the magic signature info. For enter and
enter token events, this is the MINTER_ADDRESS. For transact events,
this is the aliased or non-aliased sender.