AggregateFills

Struct AggregateFills 

pub struct AggregateFills { /* private fields */ }
The aggregate fills, to be populated via block extracts. Generally used to hold a running total of fills for a given user and asset across a block or set of transactions.

We use the following terminology:

Example

let mut context = AggregateFills::default();
// The first argument is the chain ID of the chain that emitted the event
// in this case, Ethereum.
context.add_fill(1, &fill);
context.checked_remove_order(&order)?;

Implementations

Source

impl AggregateFills

pub fn new() -> Self

Create a new aggregate.

pub fn filled(&self, output_asset: &(u64, Address), recipient: Address) -> U256

Get the fill balance a specific asset for a specific user.

pub fn check_filled( &self, output_asset: &(u64, Address), recipient: Address, amount: U256, ) -> Result<(), MarketError>

Check if the context has enough filled for the asset, recipient, and amount.

pub fn add_raw_fill( &mut self, chain_id: u64, asset: Address, recipient: Address, amount: U256, )

Add an unstructured fill to the context. The chain_id is the ID of of the chain on which the fill occurred.

pub fn add_fill(&mut self, chain_id: u64, fill: &Filled)

Ingest a new fill into the aggregate. The chain_id is the ID of the chain which emitted the event.

Note:

This uses saturating arithmetic to avoid panics. If filling more than U256::MAX, re-examine life choices and don’t do that.

pub fn add_signed_fill(&mut self, chain_id: u64, fill: &SignedFill)

Ingest a SignedFill into the aggregate. The chain_id is the ID of the chain which emitted the event.

Note:

This uses saturating arithmetic to avoid panics. If filling more than U256::MAX, re-examine life choices and don’t do that.

pub fn absorb(&mut self, other: &Self)

Absorb the fills from another context.

pub fn unchecked_unabsorb(&mut self, other: &Self) -> Result<(), MarketError>

Unabsorb the fills from another context.

pub fn check_aggregate( &self, aggregate: &AggregateOrders, ) -> Result<(), MarketError>

Check that the context can remove the aggregate.

pub fn unchecked_remove_aggregate( &mut self, aggregate: &AggregateOrders, ) -> Result<(), MarketError>

Take the aggregate of some orders from the context, without checking in advance whether the context has sufficient fills to remove the aggregate. If the context does not have sufficient fills, the context will be left in a bad state after returning an error.

pub fn checked_remove_aggregate( &mut self, aggregate: &AggregateOrders, ) -> Result<(), MarketError>

Remove the aggregate of some orders from the context, checking in advance that the context has sufficient fills to remove the aggregate.

pub fn check_order(&self, order: &Order) -> Result<(), MarketError>

Check that the context can take the order.

pub fn checked_remove_order(&mut self, order: &Order) -> Result<(), MarketError>

Take the order from the context, checking in advance that the context has sufficient fills to remove the order.

pub fn unchecked_remove_order( &mut self, order: &Order, ) -> Result<(), MarketError>

Take the order from the context, without checking in advance that the context has sufficient fills to remove the order. If the context does not have sufficient fills, the context will be left in a bad state after returning an error.

pub const fn fills(&self) -> &HashMap<(u64, Address), HashMap<Address, U256>>

Borrow the current fill mapping.

pub const fn fills_mut( &mut self, ) -> &mut HashMap<(u64, Address), HashMap<Address, U256>>

Mutably borrow the current fill mapping

pub fn check_ru_tx_events( &self, fills: &AggregateFills, orders: &AggregateOrders, ) -> Result<(), MarketError>

Check the events emitted by a rollup transaction against the context.

This will process all fills first, and all orders second.

pub fn checked_remove_ru_tx_events( &mut self, fills: &AggregateFills, orders: &AggregateOrders, ) -> Result<(), MarketError>

Check and remove the events emitted by a rollup transaction. This function allows atomic ingestion of multiple Fills and Orders. If the check fails, the aggregate will not be mutated.

This will process all fills first, and all orders second.

pub fn unchecked_remove_ru_tx_events( &mut self, fills: &AggregateFills, orders: &AggregateOrders, ) -> Result<(), MarketError>

Check and remove the events emitted by a rollup transaction. This function allows atomic ingestion of multiple Fills and Orders. If the check fails, the aggregate may be mutated.