pub struct AggregateOrders {
pub outputs: HashMap<(u64, Address), HashMap<Address, U256>>,
pub inputs: HashMap<Address, U256>,
}Expand description
Aggregated orders for a transaction or set of transactions.
Fields
outputs: HashMap<(u64, Address), HashMap<Address, U256>>Outputs to be transferred to the user. These may be on the rollup or the host or potentially elsewhere in the future. (chain_id, token) -> recipient -> amount
inputs: HashMap<Address, U256>Inputs to be transferred to the filler. These are always on the rollup.
Implementations
Sourceimpl AggregateOrders
impl AggregateOrders
Sourcepub fn new() -> Self
pub fn new() -> Self
Instantiate a new AggregateOrders.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Instantiate a new AggregateOrders with a custom capacity. The
capcity is for the number of assets in inputs or outputs.
Sourcepub fn ingest_signed(&mut self, order: &SignedOrder)
pub fn ingest_signed(&mut self, order: &SignedOrder)
Ingest a signed order into the aggregate orders.
Sourcepub fn extend<'a>(&mut self, orders: impl IntoIterator<Item = &'a Order>)
pub fn extend<'a>(&mut self, orders: impl IntoIterator<Item = &'a Order>)
Extend the orders with a new set of orders.
Sourcepub fn extend_signed<'a>(
&mut self,
orders: impl IntoIterator<Item = &'a SignedOrder>,
)
pub fn extend_signed<'a>( &mut self, orders: impl IntoIterator<Item = &'a SignedOrder>, )
Extend the orders with a new set of signed orders.
Sourcepub fn target_chain_ids(&self) -> Vec<u64>
pub fn target_chain_ids(&self) -> Vec<u64>
Get the unique target chain ids for the aggregated outputs.