Struct MagicSig

pub struct MagicSig {
    pub ty: MagicSigInfo,
    pub txid: B256,
    pub event_idx: usize,
}
A magic signature, containing information about the host-chain event which caused the rollup transaction to occur.

This is used to “recover” the sender of a transaction that is not actually signed by the sender. This is used for enter events, enter token events, and transact events.

Magic signatures are used for Signet system events to allow the system to “recover” the sender of a transaction that is not actually signed by the sender. This is used for enter events, enter token events, and transact events. These signatures contain the sender, a sentinel, and a type flag, and are used by the RPC and other systems to determine the sender of the “transaction”.

The magic signature format is as follows:

  • odd_y_parity: RESERVED (false)
  • r: 32-byte txid of the transaction that emitted the event
  • s:
    • [0..4]: A 4-byte sentinel value (0xffeeddcc).
    • [4..8]: A 4-bytes BE u32 containing the index of the event in the transaction’s log array.
    • [8..9]: A 1-byte flag (0x01 for enter, 0x02 for enter token, 0x03 for transact).
    • [9..12]: A 3-byte RESERVED region.
    • [12..32]: For transact events, (flag byte 3) the sender’s address. RESERVED otherwise.

Because Ethereum-like chains enforce low-S signatures, the S value of the magic signature is invalid for Ethereum-based chains supporting EIP-2. This means that the magic signature is never a valid signature for any relevant Ethereum-like chain.

Fields

ty: MagicSigInfo

The type of event, with any additional information.

txid: B256

The transaction ID of the host chain transaction that emitted the event.

event_idx: usize

The index of the event in the transaction’s log array.

Implementations

Source

impl MagicSig

pub fn try_from_signature(sig: &Signature) -> Option<Self>

Try to MagicSig from a signature.

pub const fn enter(txid: B256, event_idx: usize) -> Self

Create a new MagicSig for an enter event.

pub const fn enter_token(txid: B256, event_idx: usize) -> Self

Create a new MagicSig for an enter token event.

pub const fn transact(txid: B256, event_idx: usize, sender: Address) -> Self

Create a new MagicSig for a transact event.

pub const fn sender(&self) -> Address

Get the sender of the magic signature.