UnsignedFill

Struct UnsignedFill 

pub struct UnsignedFill<'a> { /* private fields */ }
An UnsignedFill is a builder type used to easily transform Orders or AggregateOrders into a SignedFill with correct permit2 semantics.

Implementations

Source

impl<'a> UnsignedFill<'a>

pub fn new() -> Self

Get a new UnsignedFill from a set of AggregateOrders.

pub fn fill_raw(self, order: &Order) -> UnsignedFill<'static>

Add an Order to the UnsignedFill.

pub fn fill(self, order: &SignedOrder) -> UnsignedFill<'static>

Add a SignedOrder to the UnsignedFill.

pub fn with_nonce(self, nonce: u64) -> Self

Add a Permit2 nonce to the UnsignedFill.

pub fn with_deadline(self, deadline: u64) -> Self

Add a deadline to the UnsignedFill, after which it cannot be mined.

pub fn with_ru_chain_id(self, ru_chain_id: u64) -> Self

👎Deprecated since 0.14.1: Use with_chain instead.

Add the rollup chain id to the UnsignedFill.

pub fn with_chain(self, constants: SignetSystemConstants) -> Self

Add the chain ids and Orders contract addresses used for signing the Fill. MUST call before sign or sign_for.

pub async fn sign<S: Signer>( &self, signer: &S, ) -> Result<HashMap<u64, SignedFill>, SigningError>

Sign the UnsignedFill, generating a SignedFill for each target chain. Use if Filling Orders with the same signing key on every chain.

pub async fn sign_for<S: Signer>( &self, target_chain_id: u64, signer: &S, ) -> Result<SignedFill, SigningError>

Sign the UnsignedFill for a specific target chain. Use if Filling Orders with different signing keys on respective target chains.

Warning ⚠️

All Outputs MUST be filled on all target chains, else the Order Inputs will not be transferred on the rollup. Take care when using this function to produce SignedFills for every target chain.