pub struct UnsignedOrder<'a> { /* private fields */ }Expand description
An UnsignedOrder is a helper type used to easily transform an Order into a SignedOrder with correct permit2 semantics. Users can do: let signed_order = UnsignedOrder::from(order).with_chain(rollup_chain_id, rollup_order_address).sign(signer)?; TxCache::new(tx_cache_endpoint).forward_order(signed_order);
Implementations
Sourceimpl<'a> UnsignedOrder<'a>
impl<'a> UnsignedOrder<'a>
Sourcepub fn with_raw_input(self, input: Input) -> UnsignedOrder<'static>
pub fn with_raw_input(self, input: Input) -> UnsignedOrder<'static>
Add an input to the UnsignedOrder.
Sourcepub fn with_input(self, token: Address, amount: U256) -> UnsignedOrder<'static>
pub fn with_input(self, token: Address, amount: U256) -> UnsignedOrder<'static>
Add an input to the UnsignedOrder.
Sourcepub fn with_raw_output(self, output: Output) -> UnsignedOrder<'static>
pub fn with_raw_output(self, output: Output) -> UnsignedOrder<'static>
Add an output to the UnsignedOrder.
Sourcepub fn with_output(
self,
token: Address,
amount: U256,
recipient: Address,
chain_id: u32,
) -> UnsignedOrder<'static>
pub fn with_output( self, token: Address, amount: U256, recipient: Address, chain_id: u32, ) -> UnsignedOrder<'static>
Add an output to the UnsignedOrder.
Sourcepub fn with_deadline(self, deadline: u64) -> UnsignedOrder<'static>
pub fn with_deadline(self, deadline: u64) -> UnsignedOrder<'static>
Set the deadline on the UnsignedOrder.
Sourcepub fn with_nonce(self, nonce: u64) -> Self
pub fn with_nonce(self, nonce: u64) -> Self
Add a Permit2 nonce to the UnsignedOrder.
Sourcepub fn with_chain(self, constants: &SignetSystemConstants) -> Self
pub fn with_chain(self, constants: &SignetSystemConstants) -> Self
Add the chain id and Order contract address to the UnsignedOrder.
MUST call before sign.
Sourcepub fn to_order(&self) -> Order
pub fn to_order(&self) -> Order
Convert the UnsignedOrder into an Order, cloning the inner data if necessary.
Sourcepub fn into_order(self) -> Cow<'a, Order>
pub fn into_order(self) -> Cow<'a, Order>
Convert the UnsignedOrder into an Order
Sourcepub async fn sign<S: Signer>(
&self,
signer: &S,
) -> Result<SignedOrder, SigningError>
pub async fn sign<S: Signer>( &self, signer: &S, ) -> Result<SignedOrder, SigningError>
Sign the UnsignedOrder, generating a SignedOrder.