Signet-related types and utilities used throughout the SDK and node.
This is a utility and data-type crate. As a result its documentation is boring.
Re-exports
pub use signet_constants as constants;
Modules
- primitives
- Primitive block types used in Signet.
Structs
- Aggregate
Fills - The aggregate fills, to be populated via block extracts. Generally used to hold a running total of fills for a given user and asset across a block or set of transactions.
- Aggregate
Orders - Aggregated orders for a transaction or set of transactions.
- Magic
Sig - A magic signature, containing information about the host-chain event which caused the rollup transaction to occur.
- Paired
Heights - A pair of heights, one for the host chain and one for the rollup chain.
- Sign
Request - A request to sign a rollup block.
- Sign
Response - A signature response from a
RequestSigner. - Signed
Fill - SignedFill type is constructed by Fillers to fill a batch of Orders. It represents the Orders’ Outputs after they have been permit2-encoded and signed.
- Signed
Order - A SignedOrder represents a single Order after it has been permit2-encoded and signed. It is the final format signed by Users and shared with Fillers to request that an Order be filled.
- Unsigned
Fill - An
UnsignedFillis a builder type used to easily transformOrders orAggregateOrdersinto aSignedFillwith correct permit2 semantics. - Unsigned
Order - An UnsignedOrder is a helper type used to easily transform an Order into a SignedOrder with correct permit2 semantics. Users can do: let signed_order = UnsignedOrder::from(order).with_chain(rollup_chain_id, rollup_order_address).sign(signer)?; TxCache::new(tx_cache_endpoint).forward_order(signed_order);
Enums
- Magic
SigInfo - Type flag used to identify the Signet event that cauesd the rollup consensus to create this magic signature.
- Market
Error - Error type for market processing.
- Signed
Permit Error - An error that can occur when validating a signed order or fill.
- Signing
Error - An error that can occur when signing an Order or a Fill.
Traits
- Request
Signer - A
RequestSignersignsSignRequests by delegating to analloy::signers::Signer.
Functions
- alias_
address - Alias an address by adding the address alias offset.
- unalias_
address - Unalias an address by subtracting the address alias offset.