pub struct SignedFill {
pub permit: Permit2Batch,
pub outputs: Vec<Output>,
}Expand description
SignedFill type is constructed by Fillers to fill a batch of Orders. It represents the Orders’ Outputs after they have been permit2-encoded and signed.
A SignedFill corresponds to the parameters for fillPermit2 on the OrderDestination contract,
and thus contains all necessary information to fill the Order.
SignedFill is an optional part of the SignetEthBundle type. Fillers sign & send bundles which contain Order initiations & fills. Filler bundles contain:
- optionally, a host SignedFill (if any Orders contain host Outputs)
- optionally, a rollup transaction that submits a SignedFill (if any Orders contain rollup Outputs)
- rollup transactions that submit the SignedOrders
Warning ⚠️
A SignedFill must remain private until it is mined, as there is no guarantee
that desired Order Inputs will be received in return for the Outputs offered by the signed Permit2Batch.
SignetEthBundles are used to submit SignedFills because they must be submitted atomically
with the corresponding SignedOrder(s) in order to claim the Inputs.
It is important to use private transaction relays to send bundles containing SignedFill(s) to Builders.
Bundles can be sent to a trusted Signet Node’s signet_sendBundle endpoint.
TODO: Link to docs.
Fields
permit: Permit2BatchThe permit batch.
outputs: Vec<Output>The desired outputs.
Implementations
Sourceimpl SignedFill
impl SignedFill
Sourcepub const fn new(permit: Permit2Batch, outputs: Vec<Output>) -> Self
pub const fn new(permit: Permit2Batch, outputs: Vec<Output>) -> Self
Creates a new signed fill.
Sourcepub fn validate(&self, timestamp: u64) -> Result<(), SignedPermitError>
pub fn validate(&self, timestamp: u64) -> Result<(), SignedPermitError>
Check that this can be syntactically used as a fill.
For it to be valid:
- Deadline must be in the future.
- The permits must exactly match the ordering, token, and amount of the outputs.
Sourcepub fn to_fill_tx(&self, order_contract: Address) -> TransactionRequest
pub fn to_fill_tx(&self, order_contract: Address) -> TransactionRequest
Generate a TransactionRequest to fill the SignedFill.