pub struct SignedOrder {
pub permit: Permit2Batch,
pub outputs: Vec<Output>,
}Expand description
A SignedOrder represents a single Order after it has been permit2-encoded and signed. It is the final format signed by Users and shared with Fillers to request that an Order be filled.
It corresponds to the parameters for initiatePermit2 on the OrderOrigin contract,
and thus contains all necessary information to initiate the Order.
It can be shared with all Fillers via the Signet Node signet_sendOrder RPC call,
or shared directly with specific Filler(s) via private channels.
The type can be signed and published safely, because although the Permit2Batch allows
the Order Inputs to be transferred from the user, the Signet Node ensures that
Inputs cannot be transferred until the Order Outputs have already been filled.
TODO: Link to docs.
Fields
permit: Permit2BatchThe permit batch.
outputs: Vec<Output>The desired outputs.
Implementations
Sourceimpl SignedOrder
impl SignedOrder
Sourcepub const fn new(permit: Permit2Batch, outputs: Vec<Output>) -> Self
pub const fn new(permit: Permit2Batch, outputs: Vec<Output>) -> Self
Creates a new signed order.
Sourcepub fn validate(&self, timestamp: u64) -> Result<(), SignedPermitError>
pub fn validate(&self, timestamp: u64) -> Result<(), SignedPermitError>
Check that this can be syntactically used to initiate an order.
For it to be valid:
- Deadline must be in the future.
Sourcepub fn to_initiate_tx(
&self,
filler_token_recipient: Address,
order_contract: Address,
) -> TransactionRequest
pub fn to_initiate_tx( &self, filler_token_recipient: Address, order_contract: Address, ) -> TransactionRequest
Generate a TransactionRequest to initiate the SignedOrder.