pub struct UnsignedFill<'a> { /* private fields */ }Expand description
An UnsignedFill is a helper type used to easily transform an AggregateOrder into a single SignedFill with correct permit2 semantics.
Implementations
Sourceimpl<'a> UnsignedFill<'a>
impl<'a> UnsignedFill<'a>
Sourcepub fn new(orders: &'a AggregateOrders) -> Self
pub fn new(orders: &'a AggregateOrders) -> Self
Get a new UnsignedFill from a set of AggregateOrders.
Sourcepub fn with_nonce(self, nonce: u64) -> Self
pub fn with_nonce(self, nonce: u64) -> Self
Add a Permit2 nonce to the UnsignedFill.
Sourcepub fn with_deadline(self, deadline: u64) -> Self
pub fn with_deadline(self, deadline: u64) -> Self
Add a deadline to the UnsignedFill, after which it cannot be mined.
Sourcepub fn with_chain(self, chain_id: u64, order_contract_address: Address) -> Self
pub fn with_chain(self, chain_id: u64, order_contract_address: Address) -> Self
Add the chain id and Order contract address to the UnsignedOrder.
Sourcepub async fn sign<S: Signer>(
&self,
signer: &S,
) -> Result<HashMap<u64, SignedFill>, SigningError>
pub async fn sign<S: Signer>( &self, signer: &S, ) -> Result<HashMap<u64, SignedFill>, SigningError>
Sign the UnsignedFill, generating a SignedFill for each destination chain. Use if Filling Orders with the same signing key on every chain.
Sourcepub async fn sign_for<S: Signer>(
&self,
chain_id: u64,
signer: &S,
) -> Result<SignedFill, SigningError>
pub async fn sign_for<S: Signer>( &self, chain_id: u64, signer: &S, ) -> Result<SignedFill, SigningError>
Sign the UnsignedFill for a specific destination chain. Use if Filling Orders with different signing keys on respective destination chains.
Warning ⚠️
All Outputs MUST be filled on all destination chains, else the Order Inputs will not be transferred. Take care when using this function to produce SignedFills for every destination chain.